#include "stdafx.h"
#include "Slider.h"
#include "lsapi.h"

extern CSliderApp theApp;

CString GetLSLnkImagePath(int nSliderNbr, const CString& keyName)
{
	TCHAR   temp[MAX_PATH];
	CString keyValue = GetProfileStringValue(nSliderNbr, keyName);

	// If the value starts with a $ then expand the evar and return.
	if ( keyValue.GetLength() > 2 && keyValue.GetAt(0) == _T('$')) {
		VarExpansion(temp, keyValue.GetBuffer(keyValue.GetLength()));
		keyValue = temp;
	}
	// If the value is NOT a full path then we'll add the LSImageFolder
	// evar to the path
	else if ( keyValue.GetLength() > 2 && keyValue.GetAt(1) != _T(':'))
	{
		VarExpansion(temp, TEXT("$LSImageFolder$"));
		keyValue.Insert(0, temp);
	}

	keyValue.ReleaseBuffer();
	return keyValue;

}

void ErrorLog(CString cErrorText)
{
	// Log error info
	CStdioFile f;

	CString cFilePath = theApp.m_IniFile.Left(theApp.m_IniFile.GetLength() - 13);
	cFilePath += "LsLnkError.txt";

	CString cText = _T("");

	if(f.Open(cFilePath, CFile::modeCreate | CFile::modeNoTruncate | CFile::modeWrite))
	{
		f.SeekToEnd();

		cText.Format("%s  %s", CTime::GetCurrentTime().Format("%c"), cErrorText);

		cText += '\n';
		cText += '\n';

		f.WriteString(cText);

		f.Close();
	}
}

BOOL GetLinkIcon( const CString & strLinkName, CString & strPath, int& nIconIndex ) 
{
	HRESULT hres;
	IShellLink * psl;
 
	// Call CoCreateInstance to obtain the IShellLink
	// Interface pointer. This call fails if
	// CoInitialize is not called, so it is assumed that
	// CoInitialize has been called.
	//AfxOleInit();

	hres =	CoCreateInstance(
				CLSID_ShellLink,
				0,
				CLSCTX_INPROC_SERVER,
				IID_IShellLink,
				(LPVOID *)&psl
			);

	if( SUCCEEDED(hres) ) {
		
		IPersistFile * ppf;
 
		// The IShellLink Interface supports the IPersistFile
		// interface. Get an interface pointer to it.
		hres =	psl->QueryInterface(
					IID_IPersistFile,
					(LPVOID *)&ppf
				);
		if( SUCCEEDED( hres ) ) {
			WORD wsz[MAX_PATH];
 
			//Convert the given link name string to wide character string.
#ifdef _UNICODE
			_tcsncpy(wsz, strLinkName, MAX_PATH);
#else
			MultiByteToWideChar(
				CP_ACP,
				0,
				strLinkName,
				-1,
				wsz,
				MAX_PATH
			);
#endif // _UNICODE

			//Load the file.
			hres = ppf->Load( wsz, STGM_READ );
			if( SUCCEEDED( hres ) ) {
				// Resolve the link by calling the Resolve() interface function.
				hres =	psl->Resolve(
							0,
							SLR_ANY_MATCH | SLR_NO_UI
						);
				if( SUCCEEDED( hres ) ) {
					TCHAR chPath[MAX_PATH];
					hres =	psl->GetIconLocation(
								chPath,
								MAX_PATH,
								&nIconIndex
							);
					if( SUCCEEDED( hres ) ) {
						// check wether the string needs expansion
 						TCHAR szPath[MAX_PATH];
						strPath = chPath;
						
						// If strPath is blank, then the icon is from the
						// executable file itself
						if(!strPath.GetLength())
							GetLinkPath(strLinkName, strPath);
					
						if( strPath.Find( TEXT('%') ) >= 0 ) {
							ExpandEnvironmentStrings( chPath, szPath, MAX_PATH );
							strPath = szPath;
						}
					}
				}
			}
			ppf->Release();
		}
		psl->Release();
	}
	return SUCCEEDED(hres) ? TRUE : FALSE;
}

// CSlider :: GetLinkPath() fills the filename and path buffer
// with relevant information
// strLinkName	- name of the link file passed into the function.
// strPath		- the buffer that will receive the filepath name.
 
BOOL GetLinkPath( const CString & strLinkName, CString & strPath ) 
{
	HRESULT hres;
	IShellLink * psl;
	WIN32_FIND_DATA wfd;
 
	// Call CoCreateInstance to obtain the IShellLink
	// Interface pointer. This call fails if
	// CoInitialize is not called, so it is assumed that
	// CoInitialize has been called.
 
	hres =	CoCreateInstance(
				CLSID_ShellLink,
				0,
				CLSCTX_INPROC_SERVER,
				IID_IShellLink,
				(LPVOID *)&psl
			);

	if( SUCCEEDED(hres) ) {
		IPersistFile * ppf;
 
		// The IShellLink Interface supports the IPersistFile
		// interface. Get an interface pointer to it.
		hres =	psl->QueryInterface(
					IID_IPersistFile,
					(LPVOID *)&ppf
				);
		if( SUCCEEDED( hres ) ) {
			WORD wsz[MAX_PATH];
 
			//Convert the given link name string to wide character string.
#ifdef _UNICODE
			_tcsncpy(wsz, strLinkName, MAX_PATH);
#else
			MultiByteToWideChar(
				CP_ACP,
				0,
				strLinkName,
				-1,
				wsz,
				MAX_PATH
			);
#endif // _UNICODE

			//Load the file.
			hres = ppf->Load( wsz, STGM_READ );
			if( SUCCEEDED( hres ) ) {
				// Resolve the link by calling the Resolve() interface function.
				hres =	psl->Resolve(
							0,
							SLR_ANY_MATCH | SLR_NO_UI
						);
				if( SUCCEEDED( hres ) ) {
					TCHAR chPath[MAX_PATH];
					hres =	psl->GetPath(
								chPath,
								MAX_PATH,
								(WIN32_FIND_DATA*)&wfd,
								SLGP_SHORTPATH
							);
					if( SUCCEEDED( hres ) ) {
						// check wether the string needs expansion
 						TCHAR szPath[MAX_PATH];
						strPath = chPath;
						if( strPath.Find( TEXT('%') ) >= 0 ) {
							ExpandEnvironmentStrings( chPath, szPath, MAX_PATH );
							strPath = szPath;
						}
					}
				}
			}
			ppf->Release();
		}
		psl->Release();
	}
	return SUCCEEDED(hres) ? TRUE : FALSE;
}

BOOL GetLinkDisplay( const CString & strLinkName, CString & strText )
{
	HRESULT hres;
	IShellLink * psl;
 
	// Call CoCreateInstance to obtain the IShellLink
	// Interface pointer. This call fails if
	// CoInitialize is not called, so it is assumed that
	// CoInitialize has been called.
 
	hres =	CoCreateInstance(
				CLSID_ShellLink,
				0,
				CLSCTX_INPROC_SERVER,
				IID_IShellLink,
				(LPVOID *)&psl
			);

	if( SUCCEEDED(hres) ) {
		IPersistFile * ppf;
 
		// The IShellLink Interface supports the IPersistFile
		// interface. Get an interface pointer to it.
		hres =	psl->QueryInterface(
					IID_IPersistFile,
					(LPVOID *)&ppf
				);
		if( SUCCEEDED( hres ) ) {
			WORD wsz[MAX_PATH];
 
			//Convert the given link name string to wide character string.
#ifdef _UNICODE
			_tcsncpy(wsz, strLinkName, MAX_PATH);
#else
			MultiByteToWideChar(
				CP_ACP,
				0,
				strLinkName,
				-1,
				wsz,
				MAX_PATH
			);
#endif // _UNICODE

			//Load the file.
			hres = ppf->Load( wsz, STGM_READ );
			if( SUCCEEDED( hres ) ) {
				// Resolve the link by calling the Resolve() interface function.
				hres =	psl->Resolve(
							0,
							SLR_ANY_MATCH | SLR_NO_UI
						);
				if( SUCCEEDED( hres ) ) {
					TCHAR chDisplay[MAX_PATH];
					hres =	psl->GetDescription(chDisplay, MAX_PATH);

					if( SUCCEEDED( hres ) ) 
						strText = chDisplay;
				}
			}
			ppf->Release();
		}
		psl->Release();
	}
	return SUCCEEDED(hres) ? TRUE : FALSE;
}

int GetNumberOfLinkFilesInDirectory(CString cPath)
{
	int nRtnAmount = 0;

	WIN32_FIND_DATA  FindData;

	HANDLE hFindHandle = FindFirstFile(cPath, &FindData);

	for(;;)
	{
		if(INVALID_HANDLE_VALUE == hFindHandle)
			break;
		else
			nRtnAmount++;

		if(!FindNextFile(hFindHandle, &FindData))
			break;
	}

	FindClose(hFindHandle);

	return nRtnAmount;

}

int GetLinkFilesInDirectory(CString cPath, CStringArray& strArray, CString cExclusionString)
{
	// Fill array up with the .lnk files names and return number of them
	CString cFileName = _T("");
	
	strArray.RemoveAll();

	WIN32_FIND_DATA  FindData;

	HANDLE hFindHandle = FindFirstFile(cPath, &FindData);

	for(;;)
	{
		if(INVALID_HANDLE_VALUE == hFindHandle)
			break;
		
		if(!(FindData.dwFileAttributes & FILE_ATTRIBUTE_DIRECTORY))
		{
			cFileName = FindData.cFileName;

			cFileName.MakeUpper();

			// Make sure its not in the exclusion list
			if(cExclusionString.Find(cFileName.Right(4)) != -1)
				// Not allowed
				TRACE1("Skipping %s\n", cFileName);
			else
				// Add it
				strArray.Add(FindData.cFileName);
		}

		if(!FindNextFile(hFindHandle, &FindData))
			break;
	}

	FindClose(hFindHandle);

	return strArray.GetSize();
}


BOOL LoadBitmap(CBitmap& pBitmap, CString cBitmapFile)
{
	//AFX_MANAGE_STATE(AfxGetStaticModuleState());
	// Load the main bitmaps if they arn't already

	if(!pBitmap.m_hObject)
	{
		HBITMAP hMainBM = (HBITMAP) LoadImage(AfxGetInstanceHandle(), cBitmapFile,
							IMAGE_BITMAP, 0, 0, LR_DEFAULTCOLOR | LR_LOADFROMFILE | LR_CREATEDIBSECTION );
		
		if(hMainBM)
		{
			pBitmap.Attach(hMainBM);
			return TRUE;
		}
		else
			return FALSE;
	}
	else
		return TRUE;

}

void DrawSemiTransparentBitmap(CDC *pDstDC, int x, int y, int nWidth, int nHeight, CDC* pSrcDC, int xSrc, int ySrc, COLORREF clrFade)
{
    CDC dcCompatible;
    CBitmap *pBitmapOld;    
	CBitmap bm;

    dcCompatible.CreateCompatibleDC(pDstDC);
    bm.CreateCompatibleBitmap(pDstDC, nWidth, nHeight);

    pBitmapOld = dcCompatible.SelectObject(&bm);
    dcCompatible.FillSolidRect(CRect(0, 0, nWidth, nHeight), clrFade);

    pDstDC->BitBlt(x, y, nWidth, nHeight, &dcCompatible, 0, 0, SRCAND);

    dcCompatible.SelectObject(pBitmapOld);
    pDstDC->BitBlt(x, y, nWidth, nHeight, pSrcDC, 0, 0, SRCPAINT);
}


void TransparentBlt( HDC dc, int nXDest, int nYDest, int nWidth, int nHeight, HDC tempDC, int nXSrc, int nYSrc, COLORREF colorTransparent ) 
{

	HDC locMemDC, maskDC;

	HBITMAP maskBitmap;
	HBITMAP bmpImage;

	//add these to store return of SelectObject() calls
	HBITMAP hOldMemBmp = NULL;
	HBITMAP hOldMaskBmp = NULL;

	maskDC = CreateCompatibleDC(tempDC);

	locMemDC = CreateCompatibleDC(tempDC);

	bmpImage = CreateCompatibleBitmap( dc, nWidth, nHeight );
	hOldMemBmp = (HBITMAP)SelectObject( locMemDC, bmpImage );


	BitBlt( locMemDC, 0,0,nWidth, nHeight, tempDC, nXSrc, nYSrc, SRCCOPY );

	// Create monochrome bitmap for the mask
	maskBitmap = CreateBitmap( nWidth, nHeight, 1, 1, NULL );
	hOldMaskBmp = (HBITMAP)SelectObject( maskDC, maskBitmap );
	SetBkColor( locMemDC, colorTransparent );

	// Create the mask from the memory DC
	BitBlt( maskDC, 0, 0, nWidth, nHeight, locMemDC, 0, 0, SRCCOPY );

	// Set the background in locMemDC to black. Using SRCPAINT with black 
	// and any other color results in the other color, thus making 
	// black the transparent color
	SetBkColor( locMemDC, RGB(0,0,0) );
	SetTextColor( locMemDC, RGB(255,255,255) );
	BitBlt( locMemDC, 0, 0, nWidth, nHeight, maskDC, 0, 0, SRCAND );

	// Set the foreground to black. See comment above.
	SetBkColor( dc, RGB(255,255,255) );
	SetTextColor( dc, RGB(0,0,0) );
	BitBlt( dc, nXDest, nYDest, nWidth, nHeight, maskDC, 0, 0, SRCAND );

	// Combine the foreground with the background
	BitBlt( dc, nXDest, nYDest, nWidth, nHeight, locMemDC, 0, 0, SRCPAINT);


	if (hOldMaskBmp)
		SelectObject( maskDC, hOldMaskBmp );
	if (hOldMemBmp)
		SelectObject( locMemDC, hOldMemBmp );

	DeleteDC(maskDC);
	DeleteDC(locMemDC);
	DeleteObject(maskBitmap);
	DeleteObject(bmpImage);
	DeleteObject(hOldMemBmp);
	DeleteObject(hOldMaskBmp);
}

HRGN BitmapToRegion (HBITMAP hBmp, COLORREF cTransparentColor, COLORREF cTolerance)
{
	HRGN hRgn = NULL;

	if (hBmp)
	{
		// Create a memory DC inside which we will scan the bitmap content
		HDC hMemDC = CreateCompatibleDC(NULL);
		if (hMemDC)
		{
			// Get bitmap size
			BITMAP bm;
			GetObject(hBmp, sizeof(bm), &bm);

			// Create a 32 bits depth bitmap and select it into the memory DC 
			BITMAPINFOHEADER RGB32BITSBITMAPINFO = {	
					sizeof(BITMAPINFOHEADER),	// biSize 
					bm.bmWidth,					// biWidth; 
					bm.bmHeight,				// biHeight; 
					1,							// biPlanes; 
					32,							// biBitCount 
					BI_RGB,						// biCompression; 
					0,							// biSizeImage; 
					0,							// biXPelsPerMeter; 
					0,							// biYPelsPerMeter; 
					0,							// biClrUsed; 
					0							// biClrImportant; 
			};
			VOID * pbits32; 
			HBITMAP hbm32 = CreateDIBSection(hMemDC, (BITMAPINFO *)&RGB32BITSBITMAPINFO, DIB_RGB_COLORS, &pbits32, NULL, 0);
			if (hbm32)
			{
				HBITMAP holdBmp = (HBITMAP)SelectObject(hMemDC, hbm32);

				// Create a DC just to copy the bitmap into the memory DC
				HDC hDC = CreateCompatibleDC(hMemDC);
				if (hDC)
				{
					// Get how many bytes per row we have for the bitmap bits (rounded up to 32 bits)
					BITMAP bm32;
					GetObject(hbm32, sizeof(bm32), &bm32);
					while (bm32.bmWidthBytes % 4)
						bm32.bmWidthBytes++;

					// Copy the bitmap into the memory DC
					HBITMAP holdBmp = (HBITMAP)SelectObject(hDC, hBmp);
					BitBlt(hMemDC, 0, 0, bm.bmWidth, bm.bmHeight, hDC, 0, 0, SRCCOPY);

					// For better performances, we will use the ExtCreateRegion() function to create the
					// region. This function take a RGNDATA structure on entry. We will add rectangles by
					// amount of ALLOC_UNIT number in this structure.
					#define ALLOC_UNIT	100
					DWORD maxRects = ALLOC_UNIT;
					HANDLE hData = GlobalAlloc(GMEM_MOVEABLE, sizeof(RGNDATAHEADER) + (sizeof(RECT) * maxRects));
					RGNDATA *pData = (RGNDATA *)GlobalLock(hData);
					pData->rdh.dwSize = sizeof(RGNDATAHEADER);
					pData->rdh.iType = RDH_RECTANGLES;
					pData->rdh.nCount = pData->rdh.nRgnSize = 0;
					SetRect(&pData->rdh.rcBound, MAXLONG, MAXLONG, 0, 0);

					// Keep on hand highest and lowest values for the "transparent" pixels
					BYTE lr = GetRValue(cTransparentColor);
					BYTE lg = GetGValue(cTransparentColor);
					BYTE lb = GetBValue(cTransparentColor);
					BYTE hr = min(0xff, lr + GetRValue(cTolerance));
					BYTE hg = min(0xff, lg + GetGValue(cTolerance));
					BYTE hb = min(0xff, lb + GetBValue(cTolerance));

					// Scan each bitmap row from bottom to top (the bitmap is inverted vertically)
					BYTE *p32 = (BYTE *)bm32.bmBits + (bm32.bmHeight - 1) * bm32.bmWidthBytes;
					for (int y = 0; y < bm.bmHeight; y++)
					{
						// Scan each bitmap pixel from left to right
						for (int x = 0; x < bm.bmWidth; x++)
						{
							// Search for a continuous range of "non transparent pixels"
							int x0 = x;
							LONG *p = (LONG *)p32 + x;
							while (x < bm.bmWidth)
							{
								BYTE b = GetRValue(*p);
								if (b >= lr && b <= hr)
								{
									b = GetGValue(*p);
									if (b >= lg && b <= hg)
									{
										b = GetBValue(*p);
										if (b >= lb && b <= hb)
											// This pixel is "transparent"
											break;
									}
								}
								p++;
								x++;
							}

							if (x > x0)
							{
								// Add the pixels (x0, y) to (x, y+1) as a new rectangle in the region
								if (pData->rdh.nCount >= maxRects)
								{
									GlobalUnlock(hData);
									maxRects += ALLOC_UNIT;
									hData = GlobalReAlloc(hData, sizeof(RGNDATAHEADER) + (sizeof(RECT) * maxRects), GMEM_MOVEABLE);
									pData = (RGNDATA *)GlobalLock(hData);
								}
								RECT *pr = (RECT *)&pData->Buffer;
								SetRect(&pr[pData->rdh.nCount], x0, y, x, y+1);
								if (x0 < pData->rdh.rcBound.left)
									pData->rdh.rcBound.left = x0;
								if (y < pData->rdh.rcBound.top)
									pData->rdh.rcBound.top = y;
								if (x > pData->rdh.rcBound.right)
									pData->rdh.rcBound.right = x;
								if (y+1 > pData->rdh.rcBound.bottom)
									pData->rdh.rcBound.bottom = y+1;
								pData->rdh.nCount++;

								// On Windows98, ExtCreateRegion() may fail if the number of rectangles is too
								// large (ie: > 4000). Therefore, we have to create the region by multiple steps.
								if (pData->rdh.nCount == 2000)
								{
									HRGN h = ExtCreateRegion(NULL, sizeof(RGNDATAHEADER) + (sizeof(RECT) * maxRects), pData);
									if (hRgn)
									{
										CombineRgn(hRgn, hRgn, h, RGN_OR);
										DeleteObject(h);
									}
									else
										hRgn = h;
									pData->rdh.nCount = 0;
									SetRect(&pData->rdh.rcBound, MAXLONG, MAXLONG, 0, 0);
								}
							}
						}

						// Go to next row (remember, the bitmap is inverted vertically)
						p32 -= bm32.bmWidthBytes;
					}

					// Create or extend the region with the remaining rectangles
					HRGN h = ExtCreateRegion(NULL, sizeof(RGNDATAHEADER) + (sizeof(RECT) * maxRects), pData);
					if (hRgn)
					{
						CombineRgn(hRgn, hRgn, h, RGN_OR);
						DeleteObject(h);
					}
					else
						hRgn = h;

					// Clean up
					GlobalFree(hData);
					SelectObject(hDC, holdBmp);
					DeleteDC(hDC);
				}

				DeleteObject(SelectObject(hMemDC, holdBmp));
			}

			DeleteDC(hMemDC);
		}	
	}

	return hRgn;
}

int GetProfileIntValue(int nSliderNbr, CString cSetting, int nDefault)
{
	// Helper to get a Value from the Format file and return the value. If the entry doesn't
	// exist, the default section will be searched
	
	CString cSection	= _T("");
	CString cDefault    = _T("");
	CString cValue      = _T("");
	TCHAR   temp[MAX_PATH];
	cSection.Format("Slider%d", nSliderNbr);
	cDefault.Format("%d", nDefault);
	
	int nRtnValue = nDefault;

	cValue = GetProfileStringValue(nSliderNbr, cSetting, cDefault);
	if ( cValue == _T("") || cValue.GetLength() < 1)
		nRtnValue = 0;
	else
		nRtnValue = _ttoi(cValue.GetBuffer(cValue.GetLength()));

	//nRtnValue = GetPrivateProfileInt(cSection, cSetting, nDefault, theApp.m_IniFile);

	// Try the current section first
	if(nDefault == nRtnValue) {
		// Hit the default section
		if ( GetPrivateProfileString("Default", cSetting, cDefault, temp, MAX_PATH, theApp.m_IniFile) ) {
			
			CString cTemp = temp;
			VarExpansion(temp, cTemp.GetBuffer(MAX_PATH));
			cValue = temp;
			nRtnValue = _ttoi(cValue.GetBuffer(cValue.GetLength()));
			if ( cValue == _T("")  || cValue.GetLength() < 1)
				nRtnValue = 0;
			else
				nRtnValue = _ttoi(cValue.GetBuffer(cValue.GetLength()));
		}
		else {
			nRtnValue = nDefault;
		}

	}
	
		return nRtnValue;
}

CString GetProfileStringValue(int nSliderNbr, CString cSetting, CString cDefault)
{
	// Helper to get a Value from the Format file and return the value. If the entry doesn't
	// exist, the default section will be searched
	CString cSection	= _T("");
	CString cRtnString	= _T("");
	TCHAR temp[MAX_PATH];

	cSection.Format("Slider%d", nSliderNbr);

	if(!GetPrivateProfileString(cSection, cSetting, "", cRtnString.GetBuffer(MAX_PATH), MAX_PATH, theApp.m_IniFile))
	{
		cRtnString.ReleaseBuffer();

		// Hit the Default Section
		if(!GetPrivateProfileString("Default", cSetting, cDefault, cRtnString.GetBuffer(MAX_PATH), MAX_PATH, theApp.m_IniFile))
		{
			//AfxMessageBox(cDefault);
			cRtnString.ReleaseBuffer();
			return cDefault;
		}	
	}

	VarExpansion(temp, cRtnString.GetBuffer(MAX_PATH));
	cRtnString = temp;

	//AfxMessageBox(cRtnString);
	cRtnString.ReleaseBuffer();

	return cRtnString;
}

// CStringArray Sorting Methods
void SortStringArray (CStringArray& csa, BOOL bDescending, BOOL bCase)
{
	int iArraySize = csa.GetSize();  

	if (iArraySize <= 0)     
		return;
	
	int iCSSize = sizeof (CString*);  
	
	void* pArrayStart = (void *)&csa[0];

	if (bDescending)
		if(bCase)
			qsort (pArrayStart, iArraySize, iCSSize, CompareDescending);  
		else
			qsort (pArrayStart, iArraySize, iCSSize, CompareDescendingNoCase); 
	else
		if(bCase)
			qsort (pArrayStart, iArraySize, iCSSize, CompareAscending);
		else
			qsort (pArrayStart, iArraySize, iCSSize, CompareAscendingNoCase);
}

int CompareAscending(const void *a, const void *b)
{
	CString *pA = (CString*)a;
	CString *pB = (CString*)b;  
	
	return (pA->Compare(*pB));
}

int CompareDescending(const void *a, const void *b)
{
	CString *pA = (CString*)a;
	CString *pB = (CString*)b;  
	
	return (-1 * (pA->Compare(*pB)));
}
int CompareAscendingNoCase(const void *a, const void *b)
{
	CString *pA = (CString*)a;
	CString *pB = (CString*)b;  
	
	return (pA->CompareNoCase(*pB));
}

int CompareDescendingNoCase(const void *a, const void *b)
{
	CString *pA = (CString*)a;
	CString *pB = (CString*)b;  
	
	return (-1 * (pA->CompareNoCase(*pB)));
}

CPoint ConvertToScreenPosition(int nXPos, int nYPos)
{
	// this will take 2 points and return a CPoint that is a point on the screen

	// If the values are negative, then they are in relation to the screen.
	// Example nXPos = -50. This means 50 from the right side. If they are positive,
	// they are relative to the left and top. Example nXPos = 20. This means
	// 20 from the left side (or just 20)

	CPoint RtnPoint;

	RtnPoint.x = 0;
	RtnPoint.y = 0;

	// Get the screen coordinates
	int nScreenWidth = GetSystemMetrics(SM_CXSCREEN);
	int nScreenHeight= GetSystemMetrics(SM_CYSCREEN);

	if(nXPos < 0)
		// Ths value is relative to the right side
		RtnPoint.x = nScreenWidth + nXPos;
	else
		RtnPoint.x = nXPos;

	if(nYPos < 0)
		// This value is relative to the bottom
		RtnPoint.y = nScreenHeight + nYPos;
	else
		RtnPoint.y = nYPos;

	return RtnPoint;

}

